@@ -8,7 +8,37 @@ App::PhotoDB - App to manage a collection of film cameras & lenses
 
 All usage of PhotoDB is via the interactive command line, which is launched by running
 
-    photodb
+    photodb [OPTIONS]
+
+=head1 OPTIONS
+
+PhotoDB uses a config file to store database connection info. You will be prompted to create this file on first run. However, you can override this by
+specifying database connection info as command line options. It is only recommended to do this for local testing. If you specify these database connection
+options, you must specify either ALL of them or NONE of them.
+
+=over
+
+=item -h --host
+
+Hostname or IP address of MySQL database server
+
+=item -s --schema
+
+Schema name of MySQL database used for PhotoDB
+
+=item -u --user
+
+MySQL username
+
+=item -p --password
+
+MySQL password
+
+=item --skipmigrations
+
+If specified, PhotoDB will not attempt to run database migrations on startup
+
+=back
 
 =head1 DESCRIPTION
 
@@ -67,6 +97,11 @@ One exception where alternative naming is also used is for negatives. A negative
 where 18 is the ID number of the film it belongs to, and 6 is the number of the frame, separated by a forward slash. This alternative system makes it easier
 to handle negatives in the darkroom. It is accepted in most places in PhotoDB where a negative ID is needed.
 
+=head3 Camera models
+
+PhotoDB makes the distinction between a camera model (any model of camera that exists) and a camera that is actually in the collection. This is because it is
+possible for you to own two cameras of the same model.
+
 =head3 Cameras and lenses
 
 Cameras and lenses are the central component of PhotoDB. Cameras and lenses can relate to each other in one of two ways:
@@ -264,9 +299,10 @@ use App::PhotoDB::handlers;
 use App::PhotoDB::commands;
 
 # Authoritative distro version
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub main {
+	my $args = shift;
 
 	# Define handlers for each command
 	my %handlers = %App::PhotoDB::commands::handlers;
@@ -274,10 +310,10 @@ sub main {
 	&welcome;
 
 	# Connect to the database
-	my $db = &db;
+	my $db = &db({args=>$args});
 
 	# Set up terminal
-	my $term = &term;
+	our $term = &term;
 
 	# Enter interactive prompt and loop until exited by user
 	while (1) {
